@@ -1,6 +1,6 @@
 # This script handles the SIP configuration and generates the Makefiles.
 #
-# Copyright (c) 2015 Riverbank Computing Limited <info@riverbankcomputing.com>
+# Copyright (c) 2017 Riverbank Computing Limited <info@riverbankcomputing.com>
 #
 # This file is part of SIP.
 #
@@ -30,8 +30,8 @@ import siputils
 
 
 # Initialise the globals.
-sip_version = 0x041301
-sip_version_str = "4.19.1"
+sip_version = 0x041308
+sip_version_str = "4.19.8"
 py_version = sys.hexversion >> 8
 py_platform = sys.platform
 plat_py_site_dir = None
@@ -220,8 +220,27 @@ def set_platform_directories():
     plat_py_conf_inc_dir = os.path.dirname(sysconfig.get_config_h_filename())
 
     if sys.platform == "win32":
-        plat_py_lib_dir = sys.prefix + "\\libs"
-        plat_bin_dir = sys.exec_prefix
+        bin_dir = sys.exec_prefix
+
+        try:
+            # Python v3.3 and later.
+            base_prefix = sys.base_prefix
+
+            if sys.exec_prefix != sys.base_exec_prefix:
+                bin_dir += '\\Scripts'
+
+        except AttributeError:
+            try:
+                # virtualenv for Python v2.
+                base_prefix = sys.real_prefix
+                bin_dir += '\\Scripts'
+
+            except AttributeError:
+                # We can't detect the base prefix in Python v3 prior to v3.3.
+                base_prefix = sys.prefix
+
+        plat_py_lib_dir = base_prefix + "\\libs"
+        plat_bin_dir = bin_dir
         plat_sip_dir = sys.prefix + "\\sip"
     else:
         lib_dir = sysconfig.get_python_lib(plat_specific=1, standard_lib=1)
@@ -399,7 +418,7 @@ def create_makefiles(macros):
         pro.write("TARGET = %s\n" % sip_module_base)
         pro.write("CONFIG -= qt\n")
         pro.write("CONFIG += warn_on exceptions_off %s %s\n" % (
-                ("staticlib" if opts.static else "plugin"),
+                ("staticlib" if opts.static else "plugin plugin_bundle"),
                 ("debug" if opts.debug else "release")))
 
         pro.write("\n")
@@ -419,27 +438,30 @@ def create_makefiles(macros):
             pro.write("""
 win32 {
     PY_MODULE = %s%s.pyd
-    target.files = %s%s.pyd
-    LIBS += %s -lpython%d.%d
-    QMAKE_POST_LINK = $(COPY_FILE) $(DESTDIR_TARGET) $$PY_MODULE
+    PY_MODULE_SRC = $(DESTDIR_TARGET)
+
+    LIBS += %s
 } else {
     PY_MODULE = %s.so
-    target.files = %s.so
-    QMAKE_POST_LINK = $(COPY_FILE) $(TARGET) $$PY_MODULE
+
+    macx {
+        PY_MODULE_SRC = $(TARGET).plugin/Contents/MacOS/$(TARGET)
+
+        QMAKE_LFLAGS += "-undefined dynamic_lookup"
+    } else {
+        PY_MODULE_SRC = $(TARGET)
+    }
 }
 
-macx {
-    QMAKE_LFLAGS += "-undefined dynamic_lookup"
-    QMAKE_LFLAGS += "-install_name $$absolute_path($$PY_MODULE, $$target.path)"
-}
+QMAKE_POST_LINK = $(COPY_FILE) $(DESTDIR_TARGET) $$PY_MODULE
+
+target.CONFIG = no_check_exist
+target.files = $$PY_MODULE
 """ % (sip_module_base, debug_suffix,
-       sip_module_base, debug_suffix,
-       link_lib_dir, (py_version >> 16), ((py_version >> 8) & 0xff),
-       sip_module_base,
+       link_lib_dir,
        sip_module_base))
 
         pro.write("\n")
-        pro.write("target.CONFIG = no_check_exist\n")
         pro.write("target.path = %s\n" % cfg.sip_mod_dir)
         pro.write("INSTALLS += target\n")
 
